summaryrefslogtreecommitdiff
path: root/sd/source/ui/slidesorter/inc/controller/SlideSorterController.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/slidesorter/inc/controller/SlideSorterController.hxx')
-rw-r--r--sd/source/ui/slidesorter/inc/controller/SlideSorterController.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/sd/source/ui/slidesorter/inc/controller/SlideSorterController.hxx b/sd/source/ui/slidesorter/inc/controller/SlideSorterController.hxx
index 58d22cf727e9..f28cd44b4467 100644
--- a/sd/source/ui/slidesorter/inc/controller/SlideSorterController.hxx
+++ b/sd/source/ui/slidesorter/inc/controller/SlideSorterController.hxx
@@ -245,11 +245,11 @@ private:
bool mbPostModelChangePending;
/** This array stores the indices of the selected page descriptors at
- the time when the edit mode is switched to EM_MASTERPAGE. With this
- we can restore the selection when switching back to EM_PAGE mode.
+ the time when the edit mode is switched to EditMode::MasterPage. With this
+ we can restore the selection when switching back to EditMode::Page mode.
*/
::std::vector<SdPage*> maSelectionBeforeSwitch;
/// The current page before the edit mode is switched to EM_MASTERPAGE.
int mnCurrentPageBeforeSwitch;
/** The master page to select after the edit mode is changed. This
@@ -245,11 +245,11 @@ private:
*/
::std::vector<SdPage*> maSelectionBeforeSwitch;
- /// The current page before the edit mode is switched to EM_MASTERPAGE.
+ /// The current page before the edit mode is switched to EditMode::MasterPage.
int mnCurrentPageBeforeSwitch;
/** The master page to select after the edit mode is changed. This